@@ -523,116 +523,234 @@ def compare_networks(model_1, model_2, pos=None, showfig=True, figsize=(15, 8),
     return(scores, adjmat_diff)
 
 
+# %% Set node properties
+def get_node_properties(model, node_color='#1f456e', node_size=None, verbose=3):
+    # https://networkx.org/documentation/networkx-1.7/reference/generated/networkx.drawing.nx_pylab.draw_networkx_nodes.html
+    nodes = {}
+    defaults={'node_color':node_color, 'node_size': node_size}
+    adjmat = model.get('adjmat', None)
+
+    if adjmat is not None:
+        if verbose>=3: print('[bnlearn]> Set node properties.')
+        # For each node, use the default node properties.
+        for node in adjmat.columns:
+            node_property = defaults.copy()
+            nodes.update({node: node_property})
+
+    # Return dict with node properties
+    return nodes
+
+
 # %% PLOT
-def plot(model, pos=None, scale=1, figsize=(15, 8), interactive=False, title='bnlearn causal network', params = {'directed':True, 'height':'800px', 'width':'70%', 'notebook':False, 'layout':None, 'font_color': False, 'bgcolor':'#ffffff'}, verbose=3):
+def plot(model,
+         pos=None,
+         scale=1,
+         interactive=False,
+         title='bnlearn causal network',
+         node_color=None,
+         node_size=None,
+         node_properties=None,
+         params_interactive={'height':'800px', 'width':'70%', 'notebook':False, 'layout':None, 'font_color': False, 'bgcolor':'#ffffff'},
+         params_static={'width':15, 'height':8, 'font_size':14, 'font_family':'sans-serif', 'alpha':0.8, 'node_shape':'o', 'layout':'fruchterman_reingold', 'font_color': '#000000', 'facecolor':'white'},
+         verbose=3):
     """Plot the learned stucture.
 
     Parameters
     ----------
     model : dict
-        Learned model from the .fit() function..
+        Learned model from the .fit() function.
     pos : graph, optional
         Coordinates of the network. If there are provided, the same structure will be used to plot the network.. The default is None.
     scale : int, optional
         Scaling parameter for the network. A larger number will linearily increase the network.. The default is 1.
-    figsize : tuple, optional
-        Figure size. The default is (15,8).
     interactive : Bool, (default: True)
-        True: Static plot
-        False: Interactive web-based graph.
-    params : dict
-        Dictionary containing parameters for the pyvis network. This only works inf interactive=True
+        True: Interactive web-based graph.
+        False: Static plot
+    title : str, optional
+        Title for the plots.
+    node_color : str, optional
+        Color each node in the network using a hex-color, such as '#8A0707' 
+    node_size : int, optional
+        Set the node size for each node in the network. The default size when using static plolts is 800, and for interactive plots it is 10. 
+    node_properties : dict (default: None).
+        Dictionary containing custom node_color and node_size parameters for the network.
+        The node properties can easily be retrieved using the function: node_properties = bn.get_node_properties(model)
+    params_interactive : dict.
+        Dictionary containing various settings in case of creating interactive plots.
+    params_static : dict.
+        Dictionary containing various settings in case of creating static plots.
     verbose : int, optional
         Print progress to screen. The default is 3.
-        0: None, 1: ERROR, 2: WARN, 3: INFO (default), 4: DEBUG, 5: TRACE
+        0: None, 1: Error, 2: Warning, 3: Info (default), 4: Debug, 5: Trace
 
     Returns
     -------
     dict containing pos and G
-        pos : list
+        pos : list.
             Positions of the nodes.
-        G : Graph
+        G : Graph.
             Graph model
+        node_properties: dict.
+            Node properties.
+
+    Examples
+    --------
+    >>> import bnlearn as bn
+    >>>
+    >>> # Load asia DAG
+    >>> df = bn.import_example(data='asia')
+    >>>
+    >>> # Structure learning of sampled dataset
+    >>> model = bn.structure_learning.fit(df)
+    >>>
+    >>> # plot static
+    >>> G = bn.plot(model)
+    >>>
+    >>> # plot interactive
+    >>> G = bn.plot(model, interactive=True)
+    >>>
+    >>> # plot interactive with various settings
+    >>> bn.plot(model, node_color='#8A0707', node_size=35, interactive=True, params_interactive = {'height':'800px', 'width':'70%', 'layout':None, 'bgcolor':'#0f0f0f0f'})
+    >>>
+    >>> # plot with node properties
+    >>> node_properties = bn.get_node_properties(model)
+    >>> # Make some changes
+    >>> node_properties['xray']['node_color']='#8A0707'
+    >>> node_properties['xray']['node_size']=50
+    >>> # Plot
+    >>> bn.plot(model, interactive=True, node_properties=node_properties)
+    >>>
 
     """
-    defaults = {'directed':True, 'height':'800px', 'width':'70%', 'notebook':False, 'heading':title, 'layout':None, 'font_color': False, 'bgcolor':'#ffffff'}
-    params = {**defaults, **params}
-
+    # Plot properties
+    defaults = {'height':'800px', 'width':'70%', 'notebook':False, 'layout':None, 'font_color': False, 'bgcolor':'#ffffff', 'directed':True}
+    params_interactive = {**defaults, **params_interactive}
+    defaults = {'height':8, 'width':15, 'font_size':14, 'font_family':'sans-serif', 'alpha':0.8, 'layout':'fruchterman_reingold', 'font_color': 'k', 'facecolor':'#ffffff', 'node_shape':'o'}
+    params_static = {**defaults, **params_static}
     out = {}
     G = nx.DiGraph()  # Directed graph
-    layout='fruchterman_reingold'
+    node_size_default = 10 if interactive else 800
+    if (node_properties is not None) and (node_size is not None):
+        if verbose>=2: print('[bnlearn]> Warning: if both "node_size" and "node_properties" are used, "node_size" will dominate the results.')
+
+    # Get node properties
+    if node_properties is None:
+        node_properties = bnlearn.get_node_properties(model)
+
+    # Set default node size based on interactive True/False
+    for key in node_properties.keys():
+        if node_properties[key]['node_size'] is None:
+            node_properties[key]['node_size']=node_size_default
 
     # Extract model if in dict
     if 'dict' in str(type(model)):
-        adjmat = model.get('adjmat', None)
-        model = model.get('model', None)
+        bnmodel = model.get('model', None)
+    else:
+        bnmodel = model.copy()
 
     # Bayesian model
-    if 'BayesianModel' in str(type(model)) or 'pgmpy' in str(type(model)):
+    if 'BayesianModel' in str(type(bnmodel)) or 'pgmpy' in str(type(bnmodel)):
         if verbose>=3: print('[bnlearn] >Plot based on BayesianModel')
         # positions for all nodes
-        pos = bnlearn.network.graphlayout(model, pos=pos, scale=scale, layout=layout, verbose=verbose)
-        # Add directed edge with weigth
-        # edges=model.edges()
-        edges=[*model.edges()]
-        for i in range(len(edges)):
-            G.add_edge(edges[i][0], edges[i][1], weight=1, color='k')
-    elif 'networkx' in str(type(model)):
+        pos = bnlearn.network.graphlayout(bnmodel, pos=pos, scale=scale, layout=params_static['layout'], verbose=verbose)
+    elif 'networkx' in str(type(bnmodel)):
         if verbose>=3: print('[bnlearn] >Plot based on networkx model')
-        G = model
-        pos = bnlearn.network.graphlayout(G, pos=pos, scale=scale, layout=layout, verbose=verbose)
+        G = bnmodel
+        pos = bnlearn.network.graphlayout(G, pos=pos, scale=scale, layout=params_static['layout'], verbose=verbose)
     else:
         if verbose>=3: print('[bnlearn] >Plot based on adjacency matrix')
-        G = bnlearn.network.adjmat2graph(adjmat)
+        G = bnlearn.network.adjmat2graph(model['adjmat'])
         # Get positions
-        pos = bnlearn.network.graphlayout(G, pos=pos, scale=scale, layout=layout, verbose=verbose)
+        pos = bnlearn.network.graphlayout(G, pos=pos, scale=scale, layout=params_static['layout'], verbose=verbose)
+
+    # get node properties
+    nodelist, node_colors, node_sizes, edge_color, edge_weights = _plot_properties(G, bnmodel, node_properties, node_color, node_size)
 
     # Make interactive or static plot
     if interactive:
-        try:
-            from pyvis import network as net
-            from IPython.core.display import display, HTML
-            # Convert adjacency matrix into Networkx Graph
-            G = bnlearn.network.adjmat2graph(adjmat)
-            # Setup of the interactive network figure
-            g = net.Network(**params)
-            # g = net.Network(directed=True, height='800px', width='70%', notebook=False, heading=title)
-            g.from_nx(G)
-            # Create advanced buttons
-            g.show_buttons(filter_=['physics'])
-            # Display
-            filename = title.strip().replace(' ','_') + '.html'
-            g.show(filename)
-            display(HTML(filename))
-            # webbrowser.open('bnlearn.html')
-        except ModuleNotFoundError:
-            if verbose>=2: print('[bnlearn] >"pyvis" module is not installed. Please pip install first: "pip install pyvis"')
+        _plot_interactive(model, params_interactive, nodelist, node_colors, node_sizes, title=title, verbose=verbose)
     else:
-        # Bootup figure
-        plt.figure(figsize=figsize)
-        # nodes
-        nx.draw_networkx_nodes(G, pos, node_size=500, alpha=0.85)
-        # edges
-        colors = [G[u][v].get('color', 'k') for u, v in G.edges()]
-        weights = [G[u][v].get('weight', 1) for u, v in G.edges()]
-        nx.draw_networkx_edges(G, pos, arrowstyle='->', edge_color=colors, width=weights)
-        # Labels
-        nx.draw_networkx_labels(G, pos, font_size=20, font_family='sans-serif')
-        # Get labels of weights
-        # labels = nx.get_edge_attributes(G,'weight')
-        # Plot weights
-        nx.draw_networkx_edge_labels(G, pos, edge_labels=nx.get_edge_attributes(G, 'weight'))
-        # Making figure nice
-        ax = plt.gca()
-        ax.set_axis_off()
-        plt.show()
+        _plot_static(model, params_static, nodelist, node_colors, node_sizes, G, edge_color, edge_weights, pos)
 
     # Store
     out['pos']=pos
     out['G']=G
+    out['node_properties']=node_properties
     return(out)
 
 
+# %% Plot interactive
+# def _plot_static(model, params_static, nodelist, node_colors, node_sizes, title, verbose=3):
+def _plot_static(model, params_static, nodelist, node_colors, node_sizes, G, edge_color, edge_weights, pos):
+    # Bootup figure
+    plt.figure(figsize=(params_static['width'], params_static['height']), facecolor=params_static['facecolor'])
+    # nodes
+    nx.draw_networkx_nodes(G, pos, nodelist=nodelist , node_size=node_sizes, alpha=params_static['alpha'], node_color=node_colors, node_shape=params_static['node_shape'])
+    # edges
+    nx.draw_networkx_edges(G, pos, arrowstyle='->', edge_color=edge_color, width=edge_weights)
+    # Labels
+    nx.draw_networkx_labels(G, pos, font_size=params_static['font_size'], font_family=params_static['font_family'], font_color=params_static['font_color'])
+    # Plot text of the weights
+    # nx.draw_networkx_edge_labels(G, pos, edge_labels=nx.get_edge_attributes(G, 'weight'), font_color=params_static['font_color'])
+    # Making figure nice
+    ax = plt.gca()
+    ax.set_axis_off()
+    plt.show()
+
+
+# %% Plot interactive
+def _plot_interactive(model, params_interactive, nodelist, node_colors, node_sizes, title, verbose=3):
+    try:
+        from pyvis import network as net
+        from IPython.core.display import display, HTML
+    except ModuleNotFoundError:
+        if verbose>=1: raise Exception('[bnlearn] >"pyvis" module is not installed. Please pip install first: "pip install pyvis"')
+    # Convert adjacency matrix into Networkx Graph
+    G = bnlearn.network.adjmat2graph(model['adjmat'])
+    # Setup of the interactive network figure
+    g = net.Network(**params_interactive)
+    # Convert from graph G
+    g.from_nx(G)
+    # g.edges
+    for i,_ in enumerate(g.nodes):
+        g.nodes[i]['color']=node_colors[np.where(nodelist==g.nodes[i].get('label'))[0][0]]
+        g.nodes[i]['size']=node_sizes[np.where(nodelist==g.nodes[i].get('label'))[0][0]]
+
+    # Create advanced buttons
+    g.show_buttons(filter_=['physics'])
+    # Display
+    filename = title.strip().replace(' ','_') + '.html'
+    g.show(filename)
+    display(HTML(filename))
+    # webbrowser.open('bnlearn.html')
+
+
+# %% Plot properties
+def _plot_properties(G, bnmodel, node_properties, node_color, node_size):
+    # Set edge properties in Graph G
+    edges=[*bnmodel.edges()]
+    for edge in edges:
+        G.add_edge(edge[0], edge[1], weight=1, color='#000000')
+    edge_color = [G[u][v].get('color') for u, v in G.edges()]
+    edge_weights = [G[u][v].get('weight') for u, v in G.edges()]
+
+    # Node properties
+    nodelist = np.unique(edges)
+    node_colors = []
+    node_sizes = []
+    for node in nodelist:
+        if node_color is not None:
+            node_colors.append(node_color)
+        else:
+            node_colors.append(node_properties[node].get('node_color'))
+        if node_size is not None:
+            node_sizes.append(node_size)
+        else:
+            node_sizes.append(node_properties[node].get('node_size'))
+    # Return
+    return nodelist, node_colors, node_sizes, edge_color, edge_weights
+
+
 # %%
 def topological_sort(adjmat, start=None):
     """Topological sort.
